library(chron)
library(MuMIn)
library(ggplot2)
library(scales)

NDVI<-read.csv((file.choose()), header=T) #rate_NDVI_paper.csv
NDVI$Date <- as.Date(NDVI$Date)
NDVI$Date
days<-julian(NDVI$Date, origin=as.Date("1990-07-14"))

dates<-as.character(c("1996-21-07", "1999-21-07", "2002-21-07", "2005-21-07", "2008-21-07", "2011-21-07", "2014-21-07", "2017-21-07"))
dates <- as.Date(dates)
dates

NDVI$days<-days
NDVI

###delete plots before fire for regression analysis
NDVI_af<-subset(NDVI, col==0) #after fire
NDVI_bf<-subset(NDVI, col==1) #before fire

###model
mod1<-lm(Rate~days+I(days^2), data=NDVI_af)
summary(mod1)

r.squaredGLMM(mod1)

##check model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))

###simulation
nsim<-2000
bsim<-sim(mod1, n.sim=nsim)

round(apply(bsim@coef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)
newdat<-expand.grid(days=seq(48,9872,length=100))

Xmat<-model.matrix(~days+I(days^2), data=newdat)

fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
fitmat
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@coef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% coef(mod1)

newdat
write.table(newdat,"newdat_NDVI.csv")
newdat

###results
head(bsim@coef)
#estimates
sum((bsim@coef[,1])>0)/nsim
sum((bsim@coef[,2])>0)/nsim
sum((bsim@coef[,3])>0)/nsim
estimates_NDVI<-apply(bsim@coef, 2 ,quantile, prob=c(0.025, 0.5, 0.975))
#slope
sum((bsim@coef[,2])>0)/nsim
sum((bsim@coef[,2]+bsim@coef[,3])>0)/nsim


###plot
plot1<-ggplot(NULL)+
  labs(x="Date")+
  labs(y="NDVI")+
  geom_hline(yintercept=0, col="grey40")+
  geom_vline(xintercept=7, col="darkred")+
  geom_point(data = NDVI_af, aes(x =days, y =Rate), alpha=0.5, col="grey60") + 
  geom_point(data = NDVI_bf, aes(x =days, y =Rate), alpha=0.5, col="black") + 
  geom_ribbon(data=newdat, aes(x=days,ymin=lower,ymax=upper),alpha=0.3, fill="grey40")+
  geom_line(data=newdat, aes(x=days,y=fit), col="grey20")+
  scale_x_continuous(breaks = c(7, 1103, 2199, 3294,4390 , 5486, 6582,7677, 8773,9869),
                     labels = c("21/07/1990","21/07/1993", "21/07/1996" , "21/07/1999"
                                , "21/07/2002", "21/07/2005", "21/07/2008", "21/07/2011"
                                , "21/07/2014", "21/07/2017"))+
 theme_bw()+
  theme(legend.position="n")+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank())+
  theme(plot.margin = unit(c(0.1,0.1,0.1, 0.1), "cm"))
plot1

###extract estimates
write.table(estimates_NDVI, "estimates_NDVI.csv", sep=",")
