###read table
cover<-read.csv((file.choose()), header=T) #choose cover_paper.csv
head(cover)

###load packages
library(ggplot2)
library(cowplot)
library(lme4)
library(arm)
library(blmeco)
library(MuMIn)
require(cairoDevice)

##########################################################################
###cover##################################################################
###calculate rates
fire<-subset(cover, fire==1)
nofire<-subset(cover, fire==0)
head(fire)
ratelichen<-(fire$lichencov-nofire$lichencov)
rateshrubs<-(fire$shrubcov-nofire$shrubcov)
rateherbs<-(fire$herbcov-nofire$herbcov)
ratemoss<-(fire$mosscov-nofire$mosscov)
ratesubshrub<-(fire$subshrubcov-nofire$subshrubcov)
rategrass<-(fire$grasscov-nofire$grasscov)
ratetrees<-(fire$treecov-nofire$treecov)
ratedata<-fire
ratedata$ratelichen<-ratelichen
ratedata$rateshrubs<-rateshrubs
ratedata$rateherbs<-rateherbs
ratedata$ratemoss<-ratemoss
ratedata$rategrass<-rategrass
ratedata$ratesubshrub<-ratesubshrub
ratedata$ratetrees<-ratetrees
ratedata$f1<-factor(ratedata$year)
ratedata

###prepare data for model input
lichens<-as.data.frame(cbind(type=rep("lichens", 30), rate=as.character(as.numeric(ratelichen)), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
bryophytes<-as.data.frame(cbind(type=rep("bryophytes", 30), rate=as.numeric(ratemoss), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
grasses<-as.data.frame(cbind(type=rep("grasses", 30), rate=as.numeric(rategrass), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
herbs<-as.data.frame(cbind(type=rep("herbs", 30), rate=as.numeric(rateherbs), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
shrubs<-as.data.frame(cbind(type=rep("shrubs", 30), rate=as.numeric(rateshrubs), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
subshrubs<-as.data.frame(cbind(type=rep("subshrubs", 30), rate=as.numeric(ratesubshrub), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))

allrates<-as.data.frame(rbind(lichens, bryophytes, grasses, herbs, subshrubs, shrubs))
allrates

allrates$fplot<-as.factor(allrates$plot)
allrates$ftype<-factor(allrates$type)
allrates$ftype<-factor(allrates$ftype, levels=c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"))
allrates$ftype
allrates$fyear<-as.factor(allrates$year)
allrates$rate<-as.numeric(as.character(allrates$rate))
allratescover<-allrates

allrates$fplot<-as.factor(allrates$plot)
mod1<-lmer(rate~fyear+ftype+fyear:ftype+(1|fplot), allrates)
summary(mod1)
#variance random factor = 0; remove random factor from model

r.squaredGLMM(mod1)

mod1<-lm(rate~fyear+ftype+fyear:ftype, allrates)
summary(mod1)

###check model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))
scatter.smooth(fitted(mod1),sqrt(abs(resid(mod1))))

###simulation
nsim<-2000
bsim<-sim(mod1, n.sim=nsim)
bsim
str(bsim)
round(apply(bsim@coef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)

newdat<-expand.grid(ftype=factor(c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                                 levels=levels(allrates$ftype)),
                    fyear=factor(c("12","28","44"),
                                 levels=levels(allrates$fyear)))
newdat

Xmat<-model.matrix(~fyear+ftype+fyear:ftype, data=newdat)
fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@coef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% coef(mod1)
newdat
write.table(newdat,"newdat.csv")


###results
head(bsim@coef)
#lichens
sum(bsim@coef[,1]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]>0)/nsim
#bryophytes
sum(bsim@coef[,1]+bsim@coef[,4]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,4]+bsim@coef[,9]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,4]+bsim@coef[,10]>0)/nsim
#grasses
sum(bsim@coef[,1]+bsim@coef[,5]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,5]+bsim@coef[,11]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,5]+bsim@coef[,12]>0)/nsim
#herbs
sum(bsim@coef[,1]+bsim@coef[,6]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,6]+bsim@coef[,13]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,6]+bsim@coef[,14]>0)/nsim
#dwarf shrubs
sum(bsim@coef[,1]+bsim@coef[,7]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,7]+bsim@coef[,15]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,7]+bsim@coef[,16]>0)/nsim
#shrubs
sum(bsim@coef[,1]+bsim@coef[,8]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,8]+bsim@coef[,17]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,8]+bsim@coef[,18]>0)/nsim

###differences
#lichens
sum(bsim@coef[,1]<bsim@coef[,1]+bsim@coef[,2])/nsim
sum(bsim@coef[,1]+bsim@coef[,2]<bsim@coef[,1]+bsim@coef[,3])/nsim
sum(bsim@coef[,1]<bsim@coef[,1]+bsim@coef[,3])/nsim
#bryophytes
sum((bsim@coef[,1]+bsim@coef[,4])<(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,4]+bsim@coef[,9]))/nsim
sum((bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,4]+bsim@coef[,9])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,4]+bsim@coef[,10]))/nsim
sum((bsim@coef[,1]+bsim@coef[,4])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,4]+bsim@coef[,10]))/nsim
#grasses
sum((bsim@coef[,1]+bsim@coef[,5])<(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,5]+bsim@coef[,11]))/nsim
sum((bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,5]+bsim@coef[,11])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,5]+bsim@coef[,12]))/nsim
sum((bsim@coef[,1]+bsim@coef[,5])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,5]+bsim@coef[,12]))/nsim
#herbs
sum((bsim@coef[,1]+bsim@coef[,6])<(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,6]+bsim@coef[,13]))/nsim
sum((bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,6]+bsim@coef[,13])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,6]+bsim@coef[,14]))/nsim
sum((bsim@coef[,1]+bsim@coef[,6])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,6]+bsim@coef[,14]))/nsim
#dwarf shrubs
sum((bsim@coef[,1]+bsim@coef[,7])<(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,7]+bsim@coef[,15]))/nsim
sum((bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,7]+bsim@coef[,15])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,7]+bsim@coef[,16]))/nsim
sum((bsim@coef[,1]+bsim@coef[,7])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,7]+bsim@coef[,16]))/nsim
#shrubs
sum((bsim@coef[,1]+bsim@coef[,8])<(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,8]+bsim@coef[,17]))/nsim
sum((bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,8]+bsim@coef[,17])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,8]+bsim@coef[,18]))/nsim
sum((bsim@coef[,1]+bsim@coef[,8])<(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,8]+bsim@coef[,18]))/nsim

#estimates
sum((bsim@coef[,1])>0)/nsim
sum((bsim@coef[,2])>0)/nsim
sum((bsim@coef[,3])>0)/nsim
sum((bsim@coef[,4])>0)/nsim
sum((bsim@coef[,5])>0)/nsim
sum((bsim@coef[,6])>0)/nsim
sum((bsim@coef[,7])>0)/nsim
sum((bsim@coef[,8])>0)/nsim
sum((bsim@coef[,9])>0)/nsim
sum((bsim@coef[,10])>0)/nsim
sum((bsim@coef[,11])>0)/nsim
sum((bsim@coef[,12])>0)/nsim
sum((bsim@coef[,13])>0)/nsim
sum((bsim@coef[,14])>0)/nsim
sum((bsim@coef[,15])>0)/nsim
sum((bsim@coef[,16])>0)/nsim
sum((bsim@coef[,17])>0)/nsim
sum((bsim@coef[,18])>0)/nsim
round(apply(bsim@coef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3)
cover_out<-as.data.frame(round(apply(bsim@coef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3))
cover_out

###plot
rect1 <- data.frame(xmin=-Inf, xmax=1.5, ymin=-Inf, ymax=Inf)
rect2 <- data.frame(xmin=2.5, xmax=3.5, ymin=-Inf, ymax=Inf)
rect3 <- data.frame(xmin=4.5, xmax=5.5, ymin=-Inf, ymax=Inf)
legend_title<-"years after fire:"
d=data.frame(x1=-Inf, x2=Inf, y1=90, y2=100)

plot1<-ggplot(data = allrates, aes(x =ftype, y =rate))+
  labs(x="")+
  labs(y="Cover (%)")+
  scale_y_continuous(limits = c(-95, 70),breaks=c(-50, 0, 50))+
  
  geom_rect(data=rect1, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  geom_rect(data=rect2, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  geom_rect(data=rect3, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  
  ###("darkred", "pink3", "azure3")
  
  geom_hline(yintercept=0, col="grey40")+
  scale_color_manual( legend_title,values=c("red4", "lightpink2", "azure4"), labels=c("12", "28", ">44"))+
  scale_x_discrete(position = "top", limits=c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                   labels=c("Lichens", "Bryophytes", "Graminoids", "Herbs", "Dwarf shrubs", "Shrubs"))+
  geom_point(aes(color=factor(fyear)), position=position_dodge(width=0.5), alpha=0.5) +
  geom_point(data=newdat, aes(x = ftype, y = fit, group=fyear) ,  position=position_dodge(width=0.5), col="black", shape=16, size=2)+
  geom_linerange(data=newdat, aes(x = ftype, y = fit, group=fyear, ymin=lower, ymax=upper),  position=position_dodge(width=0.5), col="black", size=0.5)+
  theme_bw()+
  #theme(legend.position=c(0.5, 0.1),legend.background = element_rect(fill=alpha("white",1)),legend.direction = "horizontal")+
  theme(legend.position="")+
  theme(axis.ticks.x=element_blank())+
  theme(axis.text.x = element_text(color = "grey20", size = 10))+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank())+
  theme(plot.margin = unit(c(0.1,0.1,0.1, 0.1), "cm"))
plot1
dev.off()

####################numeric change############################################
###prepare data for model input
allrates$yearN<-as.numeric(as.character(allrates$fyear))

###activate for 2nd scenario
#allrates$yearN[allrates$yearN==44]<-100

###model
mod1<-lmer(rate~yearN+ftype+yearN:ftype+(1|fplot), allrates, REML=T)
summary(mod1)

#variance random factor = 0; remove random factor from model

r.squaredGLMM(mod1)

mod1<-lm(rate~fyear+ftype+fyear:ftype, allrates)
summary(mod1)

summary(mod1)
print(mod1, correlation=TRUE) 

###model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))

###simulation
mod1<-lm(rate~yearN+ftype+yearN:ftype, allrates)
summary(mod1)

nsim<-2000
bsim<-sim(mod1, n.sim=nsim)
str(bsim)
round(apply(bsim@coef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)

newdat<-expand.grid(ftype=factor(c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                                 levels=levels(allrates$ftype)),
                    yearN=seq(12,44,length=100))
newdat

Xmat<-model.matrix(~yearN+ftype+yearN:ftype, data=newdat)
fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@coef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% coef(mod1)
newdat

###results
coef(mod1)
summary(mod1)
bsim@coef
bsim@coef[,2]
###slope lichen
sum((bsim@coef[,2]>0)/nsim)
###slope bryophytes
sum((bsim@coef[,2]+bsim@coef[,8]>0)/nsim)
###slope grasses
sum((bsim@coef[,2]+bsim@coef[,9]>0)/nsim)
###slope herbs
sum((bsim@coef[,2]+bsim@coef[,10]>0)/nsim)
###slope subshrubs
sum((bsim@coef[,2]+bsim@coef[,11]>0)/nsim)
###slope shrubs
sum((bsim@coef[,2]+bsim@coef[,12]>0)/nsim)


###########################################################################
###height##################################################################
#claculate rates
fire<-subset(cover, fire==1)
nofire<-subset(cover, fire==0)

ratelichen<-(fire$lichenheight-nofire$lichenheight)
rateshrubs<-(fire$shrubheight-nofire$shrubheight)
rateherbs<-(fire$herbheight-nofire$herbheight)
ratemoss<-(fire$mossheight-nofire$mossheight)
ratesubshrub<-(fire$subshrubheight-nofire$subshrubheight)
rategrass<-(fire$grassheight-nofire$grassheight)
ratetrees<-(fire$treeheight-nofire$treeheight)

ratedata<-fire
ratedata$ratelichen<-ratelichen
ratedata$rateshrubs<-rateshrubs
ratedata$rateherbs<-rateherbs
ratedata$ratemoss<-ratemoss
ratedata$rategrass<-rategrass
ratedata$ratesubshrub<-ratesubshrub
ratedata$ratetrees<-ratetrees
ratedata$f1<-factor(ratedata$year)
ratedata

###prepare data for model input
lichens<-as.data.frame(cbind(type=rep("lichens", 30), rate=as.character(as.numeric(ratelichen)), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
bryophytes<-as.data.frame(cbind(type=rep("bryophytes", 30), rate=as.numeric(ratemoss), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
grasses<-as.data.frame(cbind(type=rep("grasses", 30), rate=as.numeric(rategrass), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
herbs<-as.data.frame(cbind(type=rep("herbs", 30), rate=as.numeric(rateherbs), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
shrubs<-as.data.frame(cbind(type=rep("shrubs", 30), rate=as.numeric(rateshrubs), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
subshrubs<-as.data.frame(cbind(type=rep("subshrubs", 30), rate=as.numeric(ratesubshrub), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))

allrates<-as.data.frame(rbind(lichens, bryophytes, grasses, herbs, subshrubs, shrubs))
allratesheight<-allrates
allrates$fplot<-as.factor(allrates$plot)
allrates$ftype<-as.factor(allrates$type)
allrates$fyear<-as.factor(allrates$year)
allrates$rate<-as.numeric(as.character(allrates$rate))

###model
allrates$fplot<-as.factor(allrates$plot)
mod1<-lmer(rate~fyear+ftype+fyear:ftype+(1|fplot), allrates)
summary(mod1)
write.csv(allrates, "allrates2.csv")

r.squaredGLMM(mod1)

###check model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))
scatter.smooth(fitted(mod1),sqrt(abs(resid(mod1))))
qqnorm(ranef(mod1)$plot[,1], main="normap QQ random effects")
qqline(ranef(mod1)$plot[,1])

###simulation
mod1<-lmer(rate~fyear+ftype+fyear:ftype+(1|fplot), allrates, REML=T)
summary(mod1)

nsim<-2000
bsim<-sim(mod1, n.sim=nsim)
bsim
str(bsim)
round(apply(bsim@fixef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)

newdat<-expand.grid(ftype=factor(c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                                 levels=levels(allrates$ftype)),
                    fyear=factor(c("12","28","44"),
                                 levels=levels(allrates$fyear)))
newdat

Xmat<-model.matrix(~fyear+ftype+fyear:ftype, data=newdat)
fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@fixef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% fixef(mod1)

newdat
write.table(newdat,"newdat_height.csv")

###results
head(bsim@fixef)
write.table(bsim@fixef,"coefficients_height.csv")

#lichens
sum(bsim@fixef[,1]<0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]<0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]<0)/nsim
#bryophytes
sum(bsim@fixef[,1]+bsim@fixef[,4]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,4]+bsim@fixef[,9]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,4]+bsim@fixef[,10]>0)/nsim
#grasses
sum(bsim@fixef[,1]+bsim@fixef[,5]<0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,5]+bsim@fixef[,11]<0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,5]+bsim@fixef[,12]<0)/nsim
#herbs
sum(bsim@fixef[,1]+bsim@fixef[,6]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,6]+bsim@fixef[,13]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,6]+bsim@fixef[,14]>0)/nsim
#dwarf shrubs
sum(bsim@fixef[,1]+bsim@fixef[,7]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,7]+bsim@fixef[,15]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,7]+bsim@fixef[,16]>0)/nsim
#shrubs
sum(bsim@fixef[,1]+bsim@fixef[,8]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,8]+bsim@fixef[,17]>0)/nsim
sum(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,8]+bsim@fixef[,18]>0)/nsim

###differences
#lichens
sum(bsim@fixef[,1]<bsim@fixef[,1]+bsim@fixef[,2])/nsim
sum(bsim@fixef[,1]+bsim@fixef[,2]<bsim@fixef[,1]+bsim@fixef[,3])/nsim
sum(bsim@fixef[,1]<bsim@fixef[,1]+bsim@fixef[,3])/nsim
#bryophytes
sum((bsim@fixef[,1]+bsim@fixef[,4])<(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,4]+bsim@fixef[,9]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,4]+bsim@fixef[,9])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,4]+bsim@fixef[,10]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,4])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,4]+bsim@fixef[,10]))/nsim
#grasses
sum((bsim@fixef[,1]+bsim@fixef[,5])<(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,5]+bsim@fixef[,11]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,5]+bsim@fixef[,11])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,5]+bsim@fixef[,12]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,5])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,5]+bsim@fixef[,12]))/nsim
#herbs
sum((bsim@fixef[,1]+bsim@fixef[,6])<(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,6]+bsim@fixef[,13]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,6]+bsim@fixef[,13])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,6]+bsim@fixef[,14]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,6])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,6]+bsim@fixef[,14]))/nsim
#dwarf shrubs
sum((bsim@fixef[,1]+bsim@fixef[,7])<(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,7]+bsim@fixef[,15]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,7]+bsim@fixef[,15])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,7]+bsim@fixef[,16]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,7])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,7]+bsim@fixef[,16]))/nsim
#shrubs
sum((bsim@fixef[,1]+bsim@fixef[,8])<(bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,8]+bsim@fixef[,17]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,2]+bsim@fixef[,8]+bsim@fixef[,17])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,8]+bsim@fixef[,18]))/nsim
sum((bsim@fixef[,1]+bsim@fixef[,8])<(bsim@fixef[,1]+bsim@fixef[,3]+bsim@fixef[,8]+bsim@fixef[,18]))/nsim

#estimates
sum((bsim@fixef[,1])>0)/nsim
sum((bsim@fixef[,2])>0)/nsim
sum((bsim@fixef[,3])>0)/nsim
sum((bsim@fixef[,4])>0)/nsim
sum((bsim@fixef[,5])>0)/nsim
sum((bsim@fixef[,6])>0)/nsim
sum((bsim@fixef[,7])>0)/nsim
sum((bsim@fixef[,8])>0)/nsim
sum((bsim@fixef[,9])>0)/nsim
sum((bsim@fixef[,10])>0)/nsim
sum((bsim@fixef[,11])>0)/nsim
sum((bsim@fixef[,12])>0)/nsim
sum((bsim@fixef[,13])>0)/nsim
sum((bsim@fixef[,14])>0)/nsim
sum((bsim@fixef[,15])>0)/nsim
sum((bsim@fixef[,16])>0)/nsim
sum((bsim@fixef[,17])>0)/nsim
sum((bsim@fixef[,18])>0)/nsim
round(apply(bsim@fixef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3)

height_out<-as.data.frame(round(apply(bsim@fixef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3))
height_out

###plot
rect1 <- data.frame(xmin=-Inf, xmax=1.5, ymin=-Inf, ymax=Inf)
rect2 <- data.frame(xmin=2.5, xmax=3.5, ymin=-Inf, ymax=Inf)
rect3 <- data.frame(xmin=4.5, xmax=5.5, ymin=-Inf, ymax=Inf)
legend_title<-"years after fire"
d=data.frame(x1=-Inf, x2=Inf, y1=90, y2=100)

plot2<-ggplot(data = allrates, aes(x =ftype, y =rate))+
  labs(x="")+
  labs(y="Height (cm)")+
  scale_y_continuous(limits = c(-23, 60))+
  
  geom_rect(data=rect1, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  geom_rect(data=rect2, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  geom_rect(data=rect3, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  
  geom_hline(yintercept=0, col="grey40")+
  scale_color_manual( legend_title,values=c("red4", "lightpink2", "azure4"), labels=c("12", "28", ">44"))+
  scale_x_discrete(position = "bottom",  limits=c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                   labels=c("Lichens", "Bryophytes", "Graminoids", "Herbs", "Dwarf shrubs", "Shrubs"))+
  geom_point(aes(color=factor(fyear)), position=position_dodge(width=0.5), alpha=0.5) +
  geom_point(data=newdat, aes(x = ftype, y = fit, group=fyear) ,  position=position_dodge(width=0.5), col="black", shape=16, size=2)+
  geom_linerange(data=newdat, aes(x = ftype, y = fit, group=fyear, ymin=lower, ymax=upper),  position=position_dodge(width=0.5), col="black", size=0.5)+
  theme_bw()+
  theme(legend.position="none")+
  #theme(legend.position=c(0.9, 0.15),legend.background = element_rect(fill=alpha(0.1)))+
  theme(axis.text.x = element_text(color = "grey20", size = 10))+
  theme(axis.ticks.x=element_blank(), axis.text.x = element_blank())+
  
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank())+
  theme(plot.margin = unit(c(0.1,0.1,0.1, 0.1), "cm"))
plot2

####################numeric change############################################
###prepare data for model input
allrates$yearN<-as.numeric(as.character(allrates$fyear))

###activate for 2nd scenario
#allrates$yearN[allrates$yearN==44]<-100

###model
mod1<-lmer(rate~yearN+ftype+yearN:ftype+(1|fplot), allrates, REML=T)
summary(mod1)

r.squaredGLMM(mod1)

summary(mod1)
print(mod1, correlation=TRUE) 

summary(mod1)$sigma
round(fixef(mod1),3)
ranef(mod1)

###model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))
scatter.smooth(fitted(mod1),sqrt(abs(resid(mod1))))
qqnorm(ranef(mod1)$plot[,1], main="normap QQ random effects")
qqline(ranef(mod1)$plot[,1])

###simulation
mod1<-lmer(rate~yearN+ftype+yearN:ftype+(1|fplot), allrates, REML=T)
summary(mod1)

nsim<-2000
bsim<-sim(mod1, n.sim=nsim)
str(bsim)
round(apply(bsim@fixef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)

newdat<-expand.grid(ftype=factor(c("lichens", "bryophytes", "grasses", "herbs", "subshrubs", "shrubs"),
                                 levels=levels(allrates$ftype)),
                    yearN=seq(12,44,length=100))
newdat

Xmat<-model.matrix(~yearN+ftype+yearN:ftype, data=newdat)
fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@fixef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% fixef(mod1)
newdat

###results
fixef(mod1)
summary(mod1)
bsim@fixef
bsim@fixef[,2]
###slope lichen
sum((bsim@fixef[,2]>0)/nsim)
###slope bryophytes
sum((bsim@fixef[,2]+bsim@fixef[,8]>0)/nsim)
###slope grasses
sum((bsim@fixef[,2]+bsim@fixef[,9]>0)/nsim)
###slope herbs
sum((bsim@fixef[,2]+bsim@fixef[,10]>0)/nsim)
###slope subshrubs
sum((bsim@fixef[,2]+bsim@fixef[,11]>0)/nsim)
###slope shrubs
sum((bsim@fixef[,2]+bsim@fixef[,12]>0)/nsim)


##########################################################################
####################total cover & bare soil###############################
###calculate rates
fire<-subset(cover, fire==1)
nofire<-subset(cover, fire==0)
head(fire)
ratetotalcov<-(fire$totalcov-nofire$totalcov)
ratebaresoil<-(fire$baresoil-nofire$baresoil)

ratedata<-fire
ratedata$ratetotalcov<-ratetotalcov
ratedata$ratebaresoil<-ratebaresoil

###prepare data for model input
total_cover<-as.data.frame(cbind(type=rep("total_cover", 30), rate=as.character(as.numeric(ratetotalcov)), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))
bare_soil<-as.data.frame(cbind(type=rep("bare_soil", 30), rate=as.numeric(ratebaresoil), year=as.character(ratedata$year_since_fire), plot=as.character(ratedata$plot_no)))

allrates<-as.data.frame(rbind(total_cover, bare_soil))
allrates

allrates$fplot<-as.factor(allrates$plot)
allrates$ftype<-as.factor(allrates$type)
allrates$fyear<-as.factor(allrates$year)
allrates$rate<-as.numeric(as.character(allrates$rate))
allratescover<-allrates

allrates$fplot<-as.factor(allrates$plot)
mod1<-lmer(rate~fyear+ftype+fyear:ftype+(1|fplot), allrates)
summary(mod1)
#variance random factor = 0; remove random factor from model

r.squaredGLMM(mod1)

mod1<-lm(rate~fyear+ftype+fyear:ftype, allrates)
summary(mod1)

###check model assumptions
par(mfrow=c(2,2))
scatter.smooth(fitted(mod1), resid(mod1));abline(h=0, lty=2)
title("Tuckey-Anscombe Plot")
qqnorm(resid(mod1, main="normalQQ"))
qqline(resid(mod1))
scatter.smooth(fitted(mod1),sqrt(abs(resid(mod1))))

###simulation
nsim<-2000
bsim<-sim(mod1, n.sim=nsim)
bsim
str(bsim)
round(apply(bsim@coef, 2, quantile, prob=c(0.025, 0.5, 0.975)),3)

newdat<-expand.grid(ftype=factor(c("total_cover", "bare_soil"),
                                 levels=levels(allrates$ftype)),
                    fyear=factor(c("12","28","44"),
                                 levels=levels(allrates$fyear)))
newdat

Xmat<-model.matrix(~fyear+ftype+fyear:ftype, data=newdat)
fitmat<-matrix(ncol=nsim, nrow=nrow(newdat))
for(i in 1:nsim) fitmat[,i]<-Xmat %*% bsim@coef[i,]
newdat$lower<-apply(fitmat, 1, quantile, prob=0.025)
newdat$upper<-apply(fitmat, 1, quantile, prob=0.975)
newdat$fit <- Xmat %*% coef(mod1)
newdat
write.table(newdat,"newdat.csv")

###results
head(bsim@coef)

sum(bsim@coef[,1]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]>0)/nsim

sum(bsim@coef[,1]+bsim@coef[,4]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,2]+bsim@coef[,4]+bsim@coef[,5]>0)/nsim
sum(bsim@coef[,1]+bsim@coef[,3]+bsim@coef[,4]+bsim@coef[,6]>0)/nsim

#estimates
sum((bsim@coef[,1])>0)/nsim
sum((bsim@coef[,2])>0)/nsim
sum((bsim@coef[,3])>0)/nsim
sum((bsim@coef[,4])>0)/nsim
sum((bsim@coef[,5])>0)/nsim
sum((bsim@coef[,6])>0)/nsim
round(apply(bsim@coef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3)

cover_t_b_out<-as.data.frame(round(apply(bsim@coef, 2 ,quantile, prob=c(0.025, 0.5, 0.975)),3))
cover_t_b_out

###plot
rect1 <- data.frame(xmin=-Inf, xmax=1.5, ymin=-Inf, ymax=Inf)
rect2 <- data.frame(xmin=2.5, xmax=3.5, ymin=-Inf, ymax=Inf)
rect3 <- data.frame(xmin=4.5, xmax=5.5, ymin=-Inf, ymax=Inf)
legend_title<-"years after fire:"
d=data.frame(x1=-Inf, x2=Inf, y1=90, y2=100)

plot3<-ggplot(data = allrates, aes(x =ftype, y =rate))+
  labs(x="")+
  labs(y="Cover (%)")+
  scale_y_continuous(limits = c(-95, 70),breaks=c(-50, 0, 50))+
  
  geom_rect(data=rect1, aes(xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax),
            fill="grey90",
            alpha=0.5,
            inherit.aes = FALSE)+
  
  geom_hline(yintercept=0, col="grey40")+
  scale_color_manual( legend_title,values=c("red4", "lightpink2", "azure4"), labels=c("12", "28", ">44"))+
  scale_x_discrete(position = "top", limits=c("total_cover", "bare_soil"),
                   labels=c("Total cover", "Bare soil"))+
  geom_point(aes(color=factor(fyear)), position=position_dodge(width=0.5), alpha=0.5) +
  geom_point(data=newdat, aes(x = ftype, y = fit, group=fyear) ,  position=position_dodge(width=0.5), col="black", shape=16, size=2)+
  geom_linerange(data=newdat, aes(x = ftype, y = fit, group=fyear, ymin=lower, ymax=upper),  position=position_dodge(width=0.5), col="black", size=0.5)+
  theme_bw()+
  theme(legend.position="")+
  theme(axis.ticks.x=element_blank())+
  theme(axis.text.x = element_text(color = "grey20", size = 10))+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank())+
  theme(plot.margin = unit(c(0.1,0.1,0.1, 0.1), "cm"))
plot3

plot4<-ggplot(data = allrates, aes(x =ftype, y =rate))+
  labs(x="")+
  labs(y="Cover (%)")+
  scale_y_continuous(limits = c(-95, 70),breaks=c(-50, 0, 50))+
  scale_color_manual( legend_title,values=c("red4", "lightpink2", "azure4"), labels=c("12", "28", ">44"))+
  scale_x_discrete(position = "top", limits=c("total_cover", "bare_soil"),
                   labels=c("Total cover", "Bare soil"))+
  geom_point(aes(color=factor(fyear)), position=position_dodge(width=0.5), alpha=0.5) +
  geom_point(data=newdat, aes(x = ftype, y = fit, group=fyear) ,  position=position_dodge(width=0.5), col="black", shape=16, size=2)+
  geom_linerange(data=newdat, aes(x = ftype, y = fit, group=fyear, ymin=lower, ymax=upper),  position=position_dodge(width=0.5), col="black", size=0.5)+
  theme_bw()+
  theme(legend.position=c(0.5, 0.5),legend.background = element_rect(fill=alpha("white",1)),legend.direction = "vertical")+
  theme(axis.ticks.x=element_blank())+
  theme(axis.text.x = element_text(color = "grey20", size = 10))+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank())+
  theme(plot.margin = unit(c(0.1,0.1,0.1, 0.1), "cm"))
plot4

legend <- cowplot::get_legend(plot4)

fig2<-plot_grid(plot1, plot3, plot2, legend, ncol = 2, rel_widths =c(6,2.4), rel_heights = 1,   labels = c('A', 'B', 'C', ''))+
  theme(plot.margin = unit(c(0,0.3,0.3, 0.3), "cm"))
dev.off()
fig2

fig2<-plot_grid(plot1, plot2,  ncol = 1, rel_widths = 1, rel_heights = 1,   labels = c('A', 'B'))+
  cairo_ps("Figure 2.eps", height=6, width=6, fallback_resolution = 800)
fig2

##################extract estimates cover###########################
estimates_height_cover<-rbind(cover_out, height_out)
write.table(estimates_height_cover, "estimates_height_cover.csv", sep=",")

estimates_cover_t_b<-rbind(cover_t_b_out)
write.table(estimates_cover_t_b, "estimates_cover_t_b.csv", sep=",")


